#
# spec file for package helmify
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           helmify
Version:        0.4.10
Release:        1.2
Summary:        Creates Helm chart from Kubernetes yaml
License:        MIT
URL:            https://github.com/arttor/helmify
Source:         helmify-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.21

%description
CLI that creates Helm charts from kubernetes yamls.

Helmify reads a list of supported k8s objects from stdin and converts it to a helm chart. Designed to generate charts for k8s operators but not limited to. See examples of charts generated by helmify.

Supports Helm >=v3.6.0

%prep
%autosetup -p1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.version=%{version} -X main.date=$BUILD_DATE -X main.commit=v%{version}" \
   -o bin/helmify ./cmd/helmify

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Thu Nov 23 2023 kastl@b1-systems.de
- Update to version 0.4.10:
  * fix image processing for repo with port
* Thu Nov 23 2023 kastl@b1-systems.de
- Update to version 0.4.9:
  * Handle images with digests
  * chore: remove refs to deprecated io/ioutil
* Mon Oct 30 2023 kastl@b1-systems.de
- Update to version 0.4.8:
  * feat: add deployment revisionHistoryLimit
* Tue Oct 24 2023 kastl@b1-systems.de
- Update to version 0.4.7:
  * Stop trimming "controller-manager-" from PDB name
  * Add PodDisruptionBudget processor
  * fix readme wording
* Wed Sep 27 2023 kastl@b1-systems.de
- Update to version 0.4.6:
  * upgrade to go 1.21
* Thu Jul  6 2023 kastl@b1-systems.de
- Update to version 0.4.5:
  * fix goreleaser
  * added cert-manager flag to Readme
  * added cert-manager-version flag
* Mon Jun 26 2023 kastl@b1-systems.de
- Update to version 0.4.4:
  * Move existing annotations to values.yaml
  * Prevent empty white line before serviceaccount annotations
  * Properly set serviceaccount annotation variable
  * fixing cases where theres empty annotations
  * adding metaopt to processobjmeta
  * test_data and examples
  * fixing annotations yams
  * ensuring annotations are always present
  * [serviceaccount] Annotations as Values Support
* Sun Apr 30 2023 kastl@b1-systems.de
- Update to version 0.4.3:
  * Fixed the rest of the linting that went a little crazy
  * Fixed indentions that went a little crazy
  * Added security context processing for initContainers, refactor
    to reduce code duplication
  * Fixed incorrect name for the test data initContainer
  * Updated to not include initContainers:null in templates if none
    exist in the source manifest
  * Regenerated chart examples
  * This change adds support for initContainers
* Fri Apr 28 2023 kastl@b1-systems.de
- Update to version 0.4.2:
  * Add support for extracting args from containers.
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.4.1:
  * remove extra files
  * fixing logic
  * fixing review comments
  * Adding empty value for nodeSelector
* Thu Apr 13 2023 kastl@b1-systems.de
- Update to version 0.4.0:
  * #100 support filesystem as a source
  * fix: indent issue in the Makefile demo
* Mon Apr  3 2023 kastl@b1-systems.de
- Update to version 0.3.35:
  * use an alias for cert-manager
* Wed Mar 29 2023 kastl@b1-systems.de
- Update to version 0.3.34:
  * Use the latest version of cert-manager
  * Update the multiline annotation and use helmify.Values to add
    the options in the values.yaml
  * Add an option cert-manager-as-subchart to install the
    cert-manager as subchart
* Fri Mar 24 2023 kastl@b1-systems.de
- Update to version 0.3.33:
  * support StatefulSet
  * update supported resources
* Wed Mar 22 2023 kastl@b1-systems.de
- Update to version 0.3.32:
  * #50 support Job and CronJob
  * #50 move out pod processing
* Fri Mar 17 2023 kastl@b1-systems.de
- Update to version 0.3.31:
  * #30 multiline configmap values
  * replace codeclimate with golang-ci lint
  * add golang-ci lint
  * do dry-run on CI
  * #90 upgrade dependencies
* Thu Mar 16 2023 kastl@b1-systems.de
- remove tarball and use obscpio
  - use tar and recompress service at buildtime to create
    the tarball on the fly
- Update to version 0.3.30:
  * further indent container securityContext values
* Wed Mar 15 2023 kastl@b1-systems.de
- Update to version 0.3.29:
  * add missing import, re-generate examples
  * feat: add support for security context
  * always use quotes for env values
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 0.3.28:
  * fix duplicate topologySpreadConstraints
* Mon Mar 13 2023 kastl@b1-systems.de
- Update to version 0.3.27:
  * fix according to review
  * fix test
  * hide autofill behind CLI flag
  * fix: tolerations and other constraint under deployment name
  * feat: added constraints
  * feat: introduce topologyConstraints, node selectors and
    tolerations
* Fri Mar 10 2023 kastl@b1-systems.de
- Update to version 0.3.26:
  * fix: env vars with default values in values.yaml
  * modify pull policy in deployment
  * modify pull policy in deployment
  * feat: add imagePullPolicy template
* Mon Mar  6 2023 Johannes Kastl <kastl@b1-systems.de>
- new package helmify: Creates Helm chart from Kubernetes yaml
